# SigLyser
The signal processing application. \
Provides the following functionality:
1. FFT (fast fourier transform) for time domain data.
2. 3D FFT for time domain data where speed (of engine or any component) is also present.
![3D FFT](images/example.png)

4. Amplitude and RMS (root mean square) of time domain data.



## Project Log
May 2024:\
Included RMS and Amplitude Functionality

April 2024:\
Create the siglyser library after creating the base code in 2018.

## Project Road Map:

1. Documentation for existing functionality
2. Include example data within library
3. develop more examples
4. Time domain signal parsing, analyses, smoothening and standardising.
5. CSV and Excel parsing functionality without using Pandas library
6. App for siglyser (may be a separate python package)